import React, { Fragment } from 'react'
import { ArrowUpOutlined, DeleteOutlined, PlusOutlined } from '@ant-design/icons';
import {
  Row,
  Col,
  Button,
  Popover,
  Input,
  Upload,
  message,
  Alert,
  Skeleton,
  notification,
} from 'antd';
import styles from './Editor.less'
import { getImagesUploadConfig } from '@/services/manage'
import * as qiniu from 'qiniu-js'
import ReactPlayer from 'react-player'

const { TextArea } = Input

class Editor extends React.Component {
  constructor(props) {
    super(props)
    this.imgNum = 0
    let richTextDetail = this.props.richTextDetail ? this.props.richTextDetail : [ { type: 1, text: '', popVisible: false, placeholder: '请输入商品详情文字...' } ]
    this.state = {
      richTextDetail,
      lgAddVisible: false,  //底部添加详情按钮的Popover显示
      fileList: [],
      imgList: [],    // 图片上传暂存数组
      videoList: [],    //视频
    }
  }

  componentDidMount() {
    //编辑时候置入详情信息
    if (this.props.richTextDetail) {
      //编辑商品
      const richTextDetail = this.props.richTextDetail
      for (let item of richTextDetail ) {
        //图片
        if( item.type === 2 ) {
          item.src = item.image.src,
          item.width = item.image.width
          item.height = item.image.height
        }
        //视频
        if (item.type === 3) {
          item.src = item.video.src
        }
      }
      this.setState({ richTextDetail }, ()=>{
        this.props.saveItemDetail(richTextDetail)
      })
    } else {
      this.props.saveItemDetail(this.state.richTextDetail)
    }
  }


  //商品描述详情
  //输入文字
  inputTextArea(i, item, e) {
    const {richTextDetail} = this.state
    richTextDetail[i].text = e.target.value
    this.setState({ richTextDetail })
  }
  //删除功能
  delete(i, item) {
    const {richTextDetail} = this.state
    richTextDetail.splice(i, 1)
    this.setState({ richTextDetail })
  }

  //上移动
  moveUp(i, item) {
    const {richTextDetail} = this.state
    const moveItem = richTextDetail[i]
    richTextDetail[i] = richTextDetail[i - 1]
    richTextDetail[i - 1] = moveItem
    this.setState({ richTextDetail })
  }

  //插入功能
  //点击插入
  handleVisibleChange(i, visible) {   //传入Popover的visible为true
    const {richTextDetail} = this.state
    richTextDetail[i].popVisible = visible
    this.setState({ richTextDetail, insetIndex: i, lgAddVisible: false })
  }
  //插入文字
  addText() {
    let lgAddVisible = false
    const i = this.state.insetIndex
    const richTextDetail = this.state.richTextDetail
    //判断是底部按钮增加详情  还是  详情内插入详情
    if (this.state.lgAddVisible) {
      lgAddVisible = false
      richTextDetail.splice(richTextDetail.length, 0, { type: 1, text: '', popVisible: false, placeholder: '请输入商品详情文字...' })
    } else {
      richTextDetail[i].popVisible = false
      richTextDetail.splice(i + 1, 0, { type: 1, text: '', popVisible: false, placeholder: '请输入商品详情文字...' })
    }
    this.setState({ richTextDetail, lgAddVisible })
  }

  //底部按钮插入功能
  handleButtonPopoverVisible(lgAddVisible) {
    if (lgAddVisible) {
      this.setState({ lgAddVisible, insetIndex: this.state.richTextDetail.length - 1 })
    } else {
      this.setState({ lgAddVisible })
    }
  }

//冒泡排序
 bSort(arr) {
  var len = arr.length;
  for (var i = 0; i < len - 1; i++) {
    for (var j = 0; j < len - 1 - i; j++) {
      // 相邻元素两两对比，元素交换，大的元素交换到后面
      if (arr[j].index > arr[j + 1].index) {
        var temp = arr[j];
        arr[j] = arr[j + 1];
        arr[j + 1] = temp;
      }
    }
  }
  return arr;
}

  //Upload上传时的 onChange
  handleUploadChange(info) {
    //console.log(info)
    let fileList = info.fileList
    this.setState({ fileList })
  }

  //七牛上传
  customerRequest = async detail => {
    console.log('开始七牛上传: ', detail)
    const res = await getImagesUploadConfig({ fileName: detail.file.name })
    if (res.success) {
      const token = res.data.upToken
      const file = detail.file
      const key = res.data.key

      let config = {
        useCdnDomain: true,   //表示是否使用 cdn 加速域名，为布尔值，true 表示使用，默认为 false。
        region: null     // 根据具体提示修改上传地区,当为 null 或 undefined 时，自动分析上传域名区域
      };

      let putExtra = {
        fname: detail.file.name,  //文件原文件名
        params: {}, //用来放置自定义变量
        mimeType: null  //用来限制上传文件类型，为 null 时表示不对文件类型限制；限制类型放到数组里： ["image/png", "image/jpeg", "image/gif"]
      };

      let observable = qiniu.upload(file, key, token, putExtra, config);
      observable.subscribe({
        next: (res) => {
          // 主要用来展示进度
          let total = res.total
          detail.onProgress({ percent: parseInt(total.percent) })
        },
        error: (err) => {
          // 失败报错信息
          console.log('七牛上传失败：  ', err)
          message.error("上传失败");
        },
        complete: (response) => {
          // 接收成功后返回的信息
          console.log('七牛上传成功： ', response)
          const img = {
            type: 2,
            src: response.url,
            popVisible: false,
            width: response.width,
            height: response.height,
            status: 'done',
            loading: true
          }
          const { richTextDetail, insetIndex, lgAddVisible } = this.state
          const i = insetIndex
          if (lgAddVisible) {
            //底部插入图片
            richTextDetail.push(img)
            this.setState({ richTextDetail, lgAddVisible: false }, ()=>{
              detail.onSuccess(response, file)
            })
          } else {
            richTextDetail[i].popVisible = false
            richTextDetail.splice(i + 1, 0, img)
            this.setState({ richTextDetail }, ()=>{
              detail.onSuccess(response, file)
            })
          }
        }
      })
    }
  }

  //Upload上传时的 onChange
  handleVideo(info) {
    //console.log(info)
    let videoList = info.fileList
    this.setState({ videoList })
  }

  //七牛上传
  videoCustomerRequest = async detail => {
    console.log('视频开始上传: ', detail)
    this.setState({ videoUploading: true })
    const res = await getImagesUploadConfig({ fileName: detail.file.name })
    if (res.success) {
      const token = res.data.upToken
      const file = detail.file
      const key = res.data.key

      let config = {
        useCdnDomain: true,   //表示是否使用 cdn 加速域名，为布尔值，true 表示使用，默认为 false。
        region: null     // 根据具体提示修改上传地区,当为 null 或 undefined 时，自动分析上传域名区域
      };

      let putExtra = {
        fname: detail.file.name,  //文件原文件名
        params: {}, //用来放置自定义变量
        mimeType: ['video/mp4', 'video/avi']  //用来限制上传文件类型，为 null 时表示不对文件类型限制；限制类型放到数组里： ["image/png", "image/jpeg", "image/gif"]
      };

      let observable = qiniu.upload(file, key, token, putExtra, config);
      observable.subscribe({
        next: (res) => {
          // 主要用来展示进度
          let total = res.total
          detail.onProgress({ percent: parseInt(total.percent) })
        },
        error: (err) => {
          // 失败报错信息
          console.log('七牛上传失败：  ', err)
          notification.error({
            message: '上传失败',
            description: '请上传mp4，avi格式的视频'
          })
          this.setState({ videoUploading: false })
        },
        complete: (response) => {
          // 接收成功后返回的信息
          console.log('七牛上传成功： ', response)
          const video = {
            type: 3,
            src: response.url,
            popVisible: false,
            width: response.width,
            height: response.height,
            status: 'done',
            loading: true
          }
          const { richTextDetail, insetIndex, lgAddVisible } = this.state
          const i = insetIndex
          if (lgAddVisible) {
            //底部插入图片
            richTextDetail.push(video)
            this.setState({ richTextDetail, lgAddVisible: false, videoUploading: false }, () => {
              detail.onSuccess(response, file)
            })
          } else {
            richTextDetail[i].popVisible = false
            richTextDetail.splice(i + 1, 0, video)
            this.setState({ richTextDetail, videoUploading: false }, () => {
              detail.onSuccess(response, file)
            })
          }
          this.setState({ videoList: [] })
        }
      })
    }
  }

  testLog() {
    console.log(this.state.richTextDetail)
  }

  //图片加载
  loadImg(i, e) {
    const { richTextDetail } = this.state
    richTextDetail[i].loading = false
    if (e.target.naturalWidth < 750) {
      richTextDetail[i].status = 'warning'
    }
    if (richTextDetail[i].width === 0 || richTextDetail[i].height === 0) {
      richTextDetail[i].status = 'sizeError'
    }
    this.setState({ richTextDetail })
  }

  //构造插入板块
  buildAction(i, item, addContent, type) {
    return (
      <Fragment>
        <div className={styles['icon-delete']} onClick={this.delete.bind(this, i, item)}><DeleteOutlined /> 删除</div>
        <Popover
          placement="right"
          title={<span style={{ fontSize: 14 }}>添加详情</span>}
          content={addContent}
          visible={item.type === type ? item.popVisible : false}
          onVisibleChange={this.handleVisibleChange.bind(this, i)}
          trigger="click">
          <div className={styles.inset}><PlusOutlined /> 插入</div>
        </Popover>
        { i > 0 && (
          <div
            className={styles['icon-moveUp']}
            onClick={this.moveUp.bind(this, i, item)}>
            <ArrowUpOutlined /> 上移
          </div>
        ) }
      </Fragment>
    );
  }

  render() {
    const { richTextDetail, fileList, videoList, videoUploading } = this.state
    //添加详情弹窗
    const addContent = (
      <Row className={styles.addContent} type="flex">
        <Col span={8}>
          <img src={require('@/assets/addText.png')} onClick={this.addText.bind(this)} />
          <div className={styles.text} onClick={this.addText.bind(this)}>文字</div>
        </Col>
        <Col span={8}>
          <Upload
            action="http://upload.qiniu.com/"
            name='file'
            multiple={true}
            showUploadList={false}
            fileList={fileList}
            onChange={this.handleUploadChange.bind(this)}
            customRequest={this.customerRequest.bind(this)}
          >
            <img src={require('@/assets/addPhoto.png')} />
          </Upload>
          <div className={styles.text}>图片</div>
        </Col>
        <Col span={8}>
          <Upload
            action="http://upload.qiniu.com/"
            name='file'
            multiple={false}
            showUploadList={false}
            fileList={videoList}
            onChange={this.handleVideo.bind(this)}
            customRequest={this.videoCustomerRequest.bind(this)}
          >
            <img style={{ padding: 6, border: '1px solid #d8d8d8' }} src={require('@/assets/video.png')} />
          </Upload>
          <div className={styles.text}>视频</div>
        </Col>
        <Col className={videoUploading ? '' : 'hidden' } span={24} style={{ borderTop: '1px dotted #d8d8d8' }}>
          <Upload
            name='picture-card'
            multiple={false}
            fileList={videoList}
          />
        </Col>
      </Row>
    )
    return(
      <div className={styles.editor}>
        <Button className='hidden' onClick={this.testLog.bind(this)}>测试</Button>
        
        <div className={styles.richTextDetail}>
          {/*商品详情描述*/}
          {/*遍历输入框*/}
          {richTextDetail.map((item, i) => {
            const type = item.type
            if(type === 1) {
              // 文字
              return(
                <div key={i} style={{ marginBottom: 10, position: 'relative' }}>
                  <TextArea rows={4} placeholder={item.placeholder} value={item.text} style={{ width: 380, fontSize: 14 }} onChange={this.inputTextArea.bind(this, i, item)} />
                  {this.buildAction(i, item, addContent, 1) }
                </div>
              )
            } else if( type === 2 ) {
              //图片
              return(
                <div key={i} className={styles.detailImg} style={{ marginBottom: 10, position: 'relative', width: 380 }}>
                  <Skeleton className={item.loading ? '' : 'hidden'} active />
                  <img
                    className={item.loading ? 'hidden' : ''}
                    style={{ width: '100%' }}
                    src={item.src} onLoad={this.loadImg.bind(this, i)}
                  />
                  {item.status === 'error' && <Alert className={styles[`img-alert`]} message="上传失败，请删除或替换" type="error" showIcon />}
                  {item.status === 'warning' && <Alert className={styles[`img-alert`]} message={`图片过窄，当前宽度为${item.width}px， 请替换大于750px宽度的图片`} type="warning" showIcon />}
                  {item.status === 'sizeError' && <Alert className={styles[`img-alert`]} message={`图片尺寸有误(${item.width} * ${item.height})，请删除或替换`} type="error" showIcon />}
                  {this.buildAction(i, item, addContent, 2)}
                </div>
              )
            } else if( type === 3 ) {
              //视频
              return(
                <div key={i} style={{ marginBottom: 10, position: 'relative', width: 380 }}>
                  <ReactPlayer
                    className={styles.player}
                    controls={true}
                    width="100%"
                    height={250}
                    url={item.src}
                  />
                  {this.buildAction(i, item, addContent, 3)}
                </div>
              )
            }
          })}
          <Popover
            visible={this.state.lgAddVisible}
            onVisibleChange={this.handleButtonPopoverVisible.bind(this)}
            placement="right"
            title={<span style={{ fontSize: 14 }}>添加详情</span>}
            content={addContent}
            trigger="click">
            <Button className={ styles.bigButton }>添加详情</Button>
          </Popover>
          <div id="dvImageRender" style={{ display: 'none' }} />
        </div>
      </div>
    )
  }
}

export default Editor