// <MyUpload num={9} saveData={(uploadRef) => this.setState({ uploadRef })} />
// num: 图片上传数量限制
// saveData: 返回整个组件的this
// type: 'file'上传文件，默认不传为图片
//requestUrl: 配置上传接口
//md5File: function    返回md5文件加密    //https://blog.csdn.net/jj546630576/article/details/75300888   //https://github.com/forsigner/browser-md5-file
//needFileName:   请求需要发送fileName
//needMd5File: true   会在fileList里面的对象md5File添加编码信息
//needBase64: true    会在fileList里面的对象base64添加编码信息
//needSize:           b单位，文件大小限制

import React from 'react';
import { PlusOutlined, UploadOutlined } from '@ant-design/icons';
import { Upload, Modal, notification, message, Button } from 'antd';
import { getGiftIconUploadConfig } from '@/services/manage';
import * as qiniu from 'qiniu-js';
import BMF from 'browser-md5-file';
import { indexOf } from 'lodash';

class MyUpload extends React.Component {
  constructor(props) {
    super(props);
    this.imgNum = 0;
    this.state = {
      fileList: [],
      previewVisible: false, //图片预览
    };
  }

  componentDidMount() {
    if (this.props.saveData) {
      this.props.saveData(this);
    }
    if (this.props.fileList.length > 0) {
      this.setState({ fileList: this.props.fileList });
    }
  }

  getSnapshotBeforeUpdate(prevProps, prevState) {
    const props = this.props;
    if (
      props.fileList.length > 0 &&
      (!prevProps.fileList[0] || props.fileList[0].url != prevProps.fileList[0].url)
    ) {
      this.setState({ fileList: props.fileList });
    }
    return null;
  }

  componentDidUpdate(prevProps, prevState, snapshot) { }

  //冒泡排序
  bSort(arr) {
    var len = arr.length;
    for (var i = 0; i < len - 1; i++) {
      for (var j = 0; j < len - 1 - i; j++) {
        // 相邻元素两两对比，元素交换，大的元素交换到后面
        if (arr[j].index > arr[j + 1].index) {
          var temp = arr[j];
          arr[j] = arr[j + 1];
          arr[j + 1] = temp;
        }
      }
    }
    return arr;
  }

  //Upload上传时的 onChange
  handleUploadChange(info) {
    //console.log(info)
    let fileList = info.fileList;
    fileList = fileList.slice(-1 * this.props.num);
    for (let item of fileList) {
      if (item.status === 'done') {
        item.url = item.response.url;
        item.width = item.response.width;
        item.height = item.response.height;

        //File对象转base64对象
        if (this.props.needBase64) {
          const reader = new FileReader(); //全部定义一个时候，多图上传，读取多个文件会报错
          reader.readAsDataURL(item.originFileObj);
          reader.onload = () => {
            //console.log('base64: ', reader.result); //获取到base64格式图片
            item.base64 = reader.result;
          };
        }

        //需要文件的md5
        if (this.props.needMd5File) {
          const bmf = new BMF();
          bmf.md5(
            item.originFileObj, //file对象
            (err, md5) => {
              if (err) {
                console.log('err:', err);
              }
              //console.log('md5 string:', md5); // 97027eb624f85892c69c4bcec8ab0f11
              item.md5File = md5;
            },
            progress => {
              //console.log('progress number:', progress);
            },
          );
        }
      }
    }
    this.setState({ fileList });
  }

  handlePreview(file) {
    if (this.props.type === 'file') return;
    this.setState({
      previewImage: file.url || file.thumbUrl,
      previewVisible: true,
    });
  }

  handleCancel() {
    this.setState({ previewVisible: false });
  }

  //七牛上传
  customerRequest = async detail => {
    const { requestUrl, needFileName, type } = this.props;
    console.log('开始七牛上传: ', detail);
    const params = needFileName ? { fileName: detail.file.name } : {};
    const res = requestUrl ? await requestUrl(params) : await getGiftIconUploadConfig(params);
    if (res.success) {
      const token = res.data.upToken;
      const file = detail.file;
      const key = res.data.key;

      let config = {
        useCdnDomain: true, //表示是否使用 cdn 加速域名，为布尔值，true 表示使用，默认为 false。
        region: null, // 根据具体提示修改上传地区,当为 null 或 undefined 时，自动分析上传域名区域
      };

      let putExtra = {
        fname: detail.file.name, //文件原文件名
        params: {}, //用来放置自定义变量
        mimeType: null, //用来限制上传文件类型，为 null 时表示不对文件类型限制；限制类型放到数组里： ["image/png", "image/jpeg", "image/gif"]
      };

      let observable = qiniu.upload(file, key, token, putExtra, config);
      observable.subscribe({
        next: res => {
          // 主要用来展示进度
          let total = res.total;
          detail.onProgress({ percent: parseInt(total.percent) });
        },
        error: err => {
          // 失败报错信息
          console.log('七牛上传失败：  ', err);
          message.error('上传失败');
        },
        complete: response => {
          // 接收成功后返回的信息
          console.log('七牛上传成功： ', response);
          console.log(response.url);
          notification.success({
            message: type === 'file' ? '文件上传成功' : '图片上传成功',
          });
          detail.onSuccess(response, file);
        },
      });
    } else {
      console.log('error ', res);
      // message.error('图片上传配置错误', 1)
    }
  };

  //获取文件的md5，异步
  md5File(file) {
    //const file = e.target.files[0];
    bmf.md5(
      file,
      (err, md5) => {
        console.log('err:', err);
        console.log('md5 string:', md5); // 97027eb624f85892c69c4bcec8ab0f11
        this.props.md5File(md5);
      },
      progress => {
        console.log('progress number:', progress);
      },
    );
  }

  //上传之前钩子
  beforeUpload(file) {
    console.log(file)
    const { needSize, limitType } = this.props;
    return new Promise((resolve, reject) => {
      if (needSize && file.size > needSize) {
        message.error('上传文件大小超过限制');
        reject(file);
        return;
      }
      if (limitType && (file.name.indexOf(limitType) === -1 || file.type.indexOf('audio') === -1)) {
        message.error('请上传文件名为.' + limitType + '结尾的音乐文件')
        reject(file)
        return
      }
      resolve(file);
    });
  }

  render() {
    const { type } = this.props;
    const { fileList, previewImage, previewVisible } = this.state;
    const num = this.props.num || 1; //上传图片限制
    //上传七牛参数
    const uploadProps = {
      name: 'file',
      action: 'http://upload.qiniu.com/',
      headers: {
        authorization: 'authorization-text',
      },
      onChange: this.handleUploadChange.bind(this),
      beforeUpload: this.beforeUpload.bind(this),
    };
    const uploadButton =
      type === 'file' ? (
        <Button>
          <UploadOutlined /> 上传文件
        </Button>
      ) : (
          <div>
            <PlusOutlined />
            <div className="ant-upload-text">上传图片</div>
          </div>
        );

    return (
      <div>
        <Upload
          {...uploadProps}
          fileList={fileList}
          listType={type === 'file' ? 'text' : 'picture-card'}
          onPreview={this.handlePreview.bind(this)}
          multiple={num > 1 ? true : false}
          customRequest={this.customerRequest.bind(this)}
        >
          {fileList.length >= num ? null : uploadButton}
        </Upload>
        <Modal visible={previewVisible} footer={null} onCancel={this.handleCancel.bind(this)}>
          <img alt="example" style={{ width: '100%' }} src={previewImage} />
        </Modal>
        {fileList.map((item, i) => {
          return <img key={i} style={{ display: 'none' }} src={item.url} />;
        })}
      </div>
    );
  }
}

export default MyUpload;

MyUpload.defaultProps = {
  fileList: [], //编辑时候传入
  num: 1,
};
