import React, { PureComponent } from 'react';
import { Form } from '@ant-design/compatible';
import '@ant-design/compatible/assets/index.css';
import {
  Spin,
  Tag,
  Menu,
  Avatar,
  Tooltip,
  message,
  Modal,
  Input,
  Button,
  notification,
} from 'antd';
import styles from './SetPassword.less';
import { modifyPass, sendCode } from '@/services/manage'
import ValidateHelper from '@/utils/ValidateHelper'
import Security from '@/utils/Security'

const FormItem = Form.Item
const formItemLayout = {
  labelCol: {
    xs: {
      span: 24
    },
    sm: {
      span: 7
    },
  },
  wrapperCol: {
    xs: {
      span: 24
    },
    sm: {
      span: 24
    },
    md: {
      span: 17
    },
  },
};

const submitFormLayout = {
  wrapperCol: {
    xs: {
      span: 24,
      offset: 0
    },
    sm: {
      span: 10,
      offset: 7
    },
  },
};

@Form.create()
export default class SetPassword extends PureComponent {
  constructor(props) {
    super(props)
    this.state = {

    }
  }

  componentWillUnmount() {
    clearTimeout(this.timer)
  }

  //修改密码
  modifyPass() {
    this.props.form.validateFieldsAndScroll(async (err, values) => {
      if (!err) {
        console.log(values)
        if (values.password != values.password2) {
          message.error('新密码两次输入不一致')
          return
        }
        const params = {
          password: Security.encryptMd5(values.password),
          phone: values.phone,
          code: values.code
        }
        this.setState({ editPassLoading: true })
        const res = await modifyPass(params)
        this.setState({ editPassLoading: false })
        if (res.code === "OK") {
          notification['success']({
            message: '密码修改成功'
          })
          this.props.closeModal()
          this.props.form.resetFields()
        }
      }
    })
  }

  //发送验证码
  sendCode() {
    const phone = this.props.form.getFieldValue('phone')
    if (!phone) {
      message.error('请输入正确的手机号码')
      return
    }
    const params = {
      type: 3,
      phone
    }
    if (this.state.sendLoading || this.state.time > 0) return
    this.setState({ sendLoading: true }, async()=>{
      const res = await sendCode(params)
      if (res.code === "OK") {
        notification['success']({
          message: '验证码已发送，请查收'
        })
        if(res.data.code) {
          this.props.form.setFieldsValue({
            'code': res.data.code
          })
        }
        this.setState({ sendLoading: false, time: 60 }, ()=>{
          this.handleTime()
        })
      } else {
        this.setState({ sendLoading: false })
      }
    })
  }

  //倒计时
  handleTime() {
    let time = this.state.time
    if (time === 0) {
      return
    } else {
      time = time - 1
      this.setState({ time }, () => {
        this.timer = setTimeout(() => {
          this.handleTime()
        }, 1000);
      })
    }
  }

  render() {
    const { getFieldDecorator } = this.props.form
    const { editPassLoading, time, sendLoading } = this.state
    return (
      <div >
        {/*修改密码*/}
        <Modal
          className={styles.password}
          title="修改密码"
          visible={this.props.visible}
          onCancel={() => this.props.closeModal()}
          onOk={this.modifyPass.bind(this)}
          okButtonProps={{ loading: !!editPassLoading }}
        >
          <Form>
            <FormItem label="手机号" {...formItemLayout}>
              {getFieldDecorator('phone', {
                rules: [{ required: true, message: '请输入手机号' }]
              })(
                <Input style={{ width: 200, marginRight: 10 }} placeholder="请输入手机号" />
              )}
              <Button size="small" type="primary" ghost loading={!!sendLoading} disabled={time > 0 ? true : false} onClick={this.sendCode.bind(this)}>{time > 0 ? time + '秒后重新发送' : '发送验证码' }</Button>
            </FormItem>
            <FormItem label="验证码" {...formItemLayout}>
              {getFieldDecorator('code', {
                rules: [{ required: true, message: '请输入验证码' }]
              })(
                <Input type="number" placeholder="请输入验证码" />
              )}
            </FormItem>
            <FormItem label="新密码" {...formItemLayout}>
              {getFieldDecorator('password', {
                rules: [{ required: true, message: '请输入新密码' }]
              })(
                <Input type="password" placeholder="请输入新密码" />
              )}
            </FormItem>
            <FormItem label="确认密码" {...formItemLayout}>
              {getFieldDecorator('password2', {
                rules: [{ required: true, message: '请再次输入新密码' }]
              })(
                <Input type="password" placeholder="请再次输入新密码" />
              )}
            </FormItem>
          </Form>
        </Modal>
      </div>
    );
  }
}
