/**
 * 用户抽屉
 */

import { SearchOutlined, SyncOutlined } from '@ant-design/icons';
import ProTable, { ProColumns, ActionType } from '@ant-design/pro-table';
import React, { useRef, useState } from 'react'
import { Button, Drawer } from 'antd'
import { getUserList, IGetUserList } from '@/pages/Customer/services'
import * as Format from '@/utils/Format'
import { objFilter } from '@/utils/base';
import { _minerType, _minerPriceName } from '@/utils/type';
import { FormInstance } from 'antd/lib/form';
import Search from './components/Search'

interface IProps {
  drawerProps: {
    width?: number,
    visible: boolean,
    title: string,
    onClose: any,
    [propsName: string]: any
  }
  onSelect?: any,
  rowSelectionType?: 'checkbox' | 'radio',
  userList: [], //选中的用户列表，删除的时候改变值用
}

export default (props: IProps) => {

  const searchFormRef = useRef<FormInstance>()
  const actionRef = useRef<ActionType>();
  const [pagination, setPagination] = useState({ current: 1, pageSize: 20, total: 0 })
  const [loading, setLoading] = useState(false)
  const { drawerProps, rowSelectionType } = props
  const [selectedRowKeys, setSelectedRowKeys] = useState([])
  const [selectedRows, setSelectedRows] = useState([])

  //上级组件删除了选中用户，需要调整Table里面的选中
  // useEffect(() => {
  //   if (props.userList) {
  //     const keys: [] = []
  //     for (let item of props.userList) {
  //       keys.push(item.tid)
  //     }
  //     setSelectedRowKeys(keys)
  //     setSelectedRows(props.userList)
  //   } else {
  //     setSelectedRows([])
  //   }
  // }, [props.userList?.length])


  const columns: ProColumns<any>[] = [
    {
      title: '头像',
      dataIndex: 'avatar',
      valueType: 'avatar'
    },
    {
      title: '昵称',
      dataIndex: 'nickname',
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueEnum: {
        10: { text: '禁用', status: 'Error' },
        0: { text: '正常', status: 'Success' },
      },
    },
    {
      title: '手机号',
      dataIndex: 'phone',
    },
    {
      title: '团队人数',
      dataIndex: 'teamInviteCount',
    },
    {
      title: '我的邀请人数',
      dataIndex: 'myInviteCount',
    },
    {
      title: 'WOS矿机数',
      dataIndex: 'daibiCount',
    },
    {
      title: '共享值矿机数',
      dataIndex: 'quanyizhiCount',
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      render: createTime => Format.date(createTime, 'yyyy-MM-dd HH:mm')
    }
  ];

  //获取列表数据
  const fetchList = async (params: any, sort: any, filter: any) => {
    console.log('params: ', params)
    const formData: any = searchFormRef.current?.getFieldsValue()
    const fetchParams: IGetUserList = {
      pageIndex: params.current,
      pageSize: params.pageSize,
      nickname: formData.nickname,
      tid: formData.tid,
      phone: formData.phone,
      startTime: formData.time ? formData.time[0].valueOf() : '',
      endTime: formData.time ? formData.time[1].valueOf() : '',
    }
    // console.log('fetchParams: ', fetchParams)
    //存储搜索项目
    sessionStorage.setItem('getUserList', JSON.stringify(fetchParams))
    //删除未搜索项目
    objFilter(fetchParams)
    setLoading(true)
    const res = await getUserList(fetchParams)
    setLoading(false)
    if (res.success) {
      await setPagination((pagination: any) => {
        pagination.total = res.data.total
        pagination.pageSize = res.data.pageSize
        return { ...pagination }
      })
    }
    return {
      data: res.data.list,
      total: res.data.total,
      success: res.success
    }
  }

  //翻页
  const handlePage = async (current: number, pageSize?: number | undefined) => {
    await setPagination(pagination => {
      return {
        ...pagination,
        current,
        pageSize: pageSize || 20
      }
    })
    actionRef.current?.reload()
  }

  //点击查询
  const onSearch = async () => {
    await setPagination(pagination => (
      {
        ...pagination,
        current: 1
      }
    ))
    actionRef.current?.reload()
  }

  //选择列表
  const onSelectChange = (keys: any, rows: any) => {
    // console.log(keys, rows)
    setSelectedRowKeys(keys)
    setSelectedRows(rows)
  }

  const onSubmit = () => {
    console.log('selectedRows', selectedRows)
    //传输数据
    if (props.onSelect) {
      props.onSelect([...selectedRows])
    }
  }

  return (
    <Drawer
      {...drawerProps}
    >
      <Search
        formRef={searchFormRef}
      />
      <ProTable
        bordered
        actionRef={actionRef}
        rowKey="tid"
        toolBarRender={() => [
          <Button style={{ marginLeft: 20 }} icon={<SyncOutlined />} onClick={() => searchFormRef.current?.resetFields()}>
            重置
            </Button>,
          <Button
            type="primary"
            loading={loading}
            icon={<SearchOutlined />}
            onClick={onSearch}
          >
            查询
           </Button>
        ]}
        footer={() => (
          <Button type="primary" onClick={onSubmit} disabled={selectedRowKeys.length === 0}>确定选择</Button>
        )}
        request={fetchList}
        columns={columns}
        //搜索配置
        search={false}
        pagination={{
          ...pagination,
          onChange: handlePage
        }}
        rowSelection={{
          type: rowSelectionType,
          onChange: onSelectChange,
          selectedRowKeys: selectedRowKeys
        }}
      />
    </Drawer>
  )
}