/**
 * 用户选择器
 */

import React, { Fragment, useState } from 'react'
import { Button, List, Avatar } from 'antd'
import CustomerDrawer from './CustomerDrawer'
import { useMount } from 'ahooks'

interface IProps {
  rowSelectionType?: 'checkbox' | 'radio',
  onSelect?: any,
  userList?: [],
  saveClearFun?: any
}

export default (props: IProps) => {
  const { rowSelectionType } = props
  const [list, setList] = useState<[]>([])
  const [drawerVisible, setDrawerVisible] = useState(false)

  useMount(() => {
    props.saveClearFun && props.saveClearFun(onClear)
  })

  const onClear = () => {
    setList([])
  }

  //选择用户
  const onSelect = (userList: any) => {
    // console.log(userList)
    setList(userList)
    setDrawerVisible(false)
    //传输选中的用户
    if (props.onSelect) {
      props.onSelect(userList)
    }
  }

  //删除选择用户
  const onDelete = (i: number) => {
    setList(list => {
      list.splice(i, 1)
      return [...list]
    })
    //传输选中的用户
    if (props.onSelect) {
      props.onSelect([])
    }
  }

  return (
    <Fragment>
      {
        list.length > 0
          ? (
            <List bordered>
              {list.map((item: any, i) => {
                return (
                  <List.Item
                    key={i}
                    actions={[<a key="list-loadmore-edit" onClick={() => onDelete(i)}>删除</a>]}
                  >
                    <List.Item.Meta
                      avatar={
                        <Avatar src={item.avatar} />
                      }
                      title={item.nickname}
                      description={
                        <Fragment>
                          <span>手机号：{item.phone}</span>
                        </Fragment>
                      }
                    />
                  </List.Item>
                )
              })}
            </List>
          )
          : <Button onClick={() => setDrawerVisible(true)}>选择用户</Button>
      }
      <CustomerDrawer
        drawerProps={{
          width: 900,
          visible: drawerVisible,
          title: '选择用户',
          onClose: () => setDrawerVisible(false)
        }}
        onSelect={onSelect}
        rowSelectionType={rowSelectionType}
        userList={list}
      />
    </Fragment>
  )
}