import React from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import { LeftOutlined, RightOutlined, SyncOutlined } from '@ant-design/icons';
import { Form } from '@ant-design/compatible';
import '@ant-design/compatible/assets/index.css';
import {
  Button,
  Input,
  Card,
  notification,
  Alert,
  DatePicker,
  Result,
  Radio,
  Select,
} from 'antd';
import { createOrEditGift, getUserInfo, editUser } from '@/services/manage'
import router from 'umi/router'
//import styles from './FormDemo.less'
import RedStar from '@/components/Custom/RedStar';
import Url from '@/utils/Url'
import moment from 'moment'
import FooterToolbar from '@/components/FooterToolbar'
import { objFilter } from '@/utils/Help';
import MyUpload from '@/components/Custom/MyUpload';

const FormItem = Form.Item;
const Option = Select.Option;
const formItemLayout = {
  labelCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 7,
    },
  },
  wrapperCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 12,
    },
    md: {
      span: 10,
    },
  },
};


@Form.create()
class FormDemo extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: Url.getQueryString('giftId') ? true : false,
      finishAdd: false,
      giftId: Url.getQueryString('giftId'),
      info: {},
    };
  }

  componentDidMount() {
    // if (this.state.giftId) {
    //   this.getUserInfo()
    // }
  }

  componentWillUnmount() {
    if (this.timer) {
      clearTimeout(this.timer);
    }
  }

  //获取礼物信息
  async getUserInfo() {
    const { giftId } = this.state;
    const res = await getUserInfo({ giftId });
    if (res.success) {
      const info = res.data
      this.props.form.setFieldsValue({
        userName: info.userName,
        userSex: info.userSex,
        userSeniority: info.userSeniority,
        userPhone: info.userPhone,
        userIntro: info.userIntro,
        userBornTime: moment(Number(info.userBornTime)),
        userDieTime: moment(Number(info.userDieTime)),
      });
      //设置头像
      if (info.userAvatar) {
        this.timer = setTimeout(() => {
          if (this.state.uploadRef) {
            this.state.uploadRef.setState({
              fileList: [
                {
                  uid: Date.now(),
                  status: 'done',
                  url: info.userAvatar,
                  name: '用户头像',
                },
              ],
            });
          }
        }, 300);
      }
      //图文详情
      this.setState({ loading: false, info });
    }
  }

  //测试
  testLog() {
    console.log(this.state);
  }

  //  提交
  handleSubmit() {
    const { form } = this.props;
    form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        this.createOrEditGift(values);
      }
    });
  }

  //添加礼物
  async createOrEditGift(values) {
    const { giftId, submitLoading, uploadRef } = this.state
    const params = {
      ...values,
      userAvatar: uploadRef.state.fileList.length === 0 ? '' : uploadRef.state.fileList[0].url,
      giftId
    }


    objFilter(params);
    console.log(`提交: `, params);
    if (submitLoading) return;
    this.setState({ submitLoading: true });
    const res = giftId ? await editUser(params) : await createOrEditGift(params);
    if (res.msg === 'err') return;
    if (res.code === 'OK') {
      notification['success']({
        message: giftId ? '礼物编辑成功' : '礼物添加成功',
      });
      this.setState({ finishAdd: true, submitLoading: false });
    } else {
      this.setState({ submitLoading: false });
    }
  }

  goBack() {
    router.go(-1);
  }

  disabledDate(current) {
    return (
      current <
      moment()
        .subtract(1, 'days')
        .endOf('day')
    );
  }

  goOnAdd() {
    this.setState({ finishAdd: false });
    this.props.form.resetFields();
    this.state.uploadRef.setState({ fileList: [] });
  }

  goList() {
    router.push('/family/list');
  }

  saveUploadRef(uploadRef) {
    this.setState({ uploadRef });
  }

  render() {
    const { giftId, loading, info } = this.state;
    const { getFieldDecorator } = this.props.form;
    if (this.state.finishAdd) {
      return (
        <Card>
          <Result
            status="success"
            title={<div>{giftId ? '礼物编辑成功' : '礼物添加成功'}</div>}
            extra={
              <div style={{ textAlign: 'center' }}>
                {giftId ? (
                  <Button type="primary" ghost onClick={() => location.reload()}>
                    <SyncOutlined />
                    重新编辑
                  </Button>
                ) : (
                  <Button type="primary" ghost onClick={this.goOnAdd.bind(this)}>
                    <LeftOutlined />
                    继续添加
                  </Button>
                )}
                <Button type="primary" style={{ marginLeft: 20 }} onClick={this.goList.bind(this)}>
                  前往礼物列表 <RightOutlined />
                </Button>
              </div>
            }
          />
        </Card>
      );
    } else {
      return (
        <PageHeaderWrapper
          title={<span onClick={this.testLog.bind(this)}>{this.props.route.name}</span>}
          onBack={ ()=> router.goBack() }
        >
          <Card title="礼物信息" loading={loading}>
            <Form>
              <FormItem label="礼物名称" {...formItemLayout}>
                {getFieldDecorator('giftName', {
                  rules: [{ required: true, message: '请输入礼物名称' }],
                })(
                  <Input placeholder="请输入礼物名称" />
                )}
              </FormItem>
              <FormItem label="礼物分类" {...formItemLayout}>
                {getFieldDecorator('giftCategory', {
                  rules: [{ required: true, message: '请选择礼物分类' }],
                })(
                  <Select placeholder="请选择礼物分类">
                    
                  </Select>
                )}
              </FormItem>
              <FormItem label={<RedStar title="礼物图片" />} {...formItemLayout}>
                <div style={{ height: 120 }}>
                  <MyUpload saveData={this.saveUploadRef.bind(this)} />
                </div>
                <Alert message="建议尺寸为750px * 750px" type="info" showIcon />
              </FormItem>

              <FormItem label="是否贴纸" {...formItemLayout}>
                {getFieldDecorator('isSticker', {
                  rules: [{ required: true, message: '请选择是否贴纸' }],
                })(
                  <Radio.Group>
                    <Radio value={1}>是</Radio>
                    <Radio value={0} style={{ marginLeft: 20 }}>
                      否
                    </Radio>
                  </Radio.Group>,
                )}
              </FormItem>

              <FooterToolbar>
                <Button
                  type="primary"
                  size="large"
                  loading={!!this.state.submitLoading}
                  onClick={this.handleSubmit.bind(this)}
                >
                  {giftId ? '确定编辑' : '确定添加'}
                </Button>
              </FooterToolbar>
            </Form>
          </Card>
        </PageHeaderWrapper>
      );
    }
  }
}

export default FormDemo;
