import { stringify } from 'querystring';
import { history, Reducer, Effect } from 'umi';

import { login } from '@/services/manage';
import { setAuthority } from '@/utils/authority';
import { getPageQuery } from '@/utils/utils';
import Cookie from '@/utils/Cookie';

export interface StateType {
  status?: 'ok' | 'error';
  type?: string;
  currentAuthority?: 'user' | 'guest' | 'admin';
}

export interface LoginModelType {
  namespace: string;
  state: StateType;
  effects: {
    login: Effect;
    logout: Effect;
  };
  reducers: {
    changeLoginStatus: Reducer<StateType>;
  };
}

const Model: LoginModelType = {
  namespace: 'login',

  state: {
    status: undefined,
  },

  effects: {
    *login({ payload }, { call, put }) {
      const res = yield call(login, payload);
      yield put({
        type: 'changeLoginStatus',
        payload: res,
      });
      // Login successfully
      if (res.success) {
        Cookie.set('_xy_music', res.data.token, {
          path: '/',
          expires: 7,
        });
        window.sessionStorage.setItem('userInfo', JSON.stringify({
          name: payload.phone,
          phone: payload.phone,
          userid: res.data.userId,
          userId: res.data.userId,
          avatar: require('@/assets/favicon.png')
        }))

        const urlParams = new URL(window.location.href);
        const params = getPageQuery();
        // let { redirect } = params as { redirect: string };
        // if (redirect) {
        //   const redirectUrlParams = new URL(redirect);
        //   if (redirectUrlParams.origin === urlParams.origin) {
        //     redirect = redirect.substr(urlParams.origin.length);
        //     if (redirect.match(/^\/.*#/)) {
        //       redirect = redirect.substr(redirect.indexOf('#') + 1);
        //     }
        //   } else {
        //     window.location.href = '/';
        //     return;
        //   }
        // }
        history.replace('/');
      }
    },

    logout() {
      const { redirect } = getPageQuery();
      // Note: There may be security issues, please note
      Cookie.remove('_xy_music', {
        path: '/',
      });
      if (window.location.pathname !== '/user/login' && !redirect) {
        history.replace({
          pathname: '/user/login',
          search: stringify({
            redirect: window.location.href,
          }),
        });
      }
    },
  },

  reducers: {
    changeLoginStatus(state, { payload }) {
      setAuthority(payload.currentAuthority);
      return {
        ...state,
        status: payload.status,
        type: payload.type,
      };
    },
  },
};

export default Model;
