import { PageContainer } from '@ant-design/pro-layout';
import { DeleteOutlined, PlusOutlined, SearchOutlined, SyncOutlined } from '@ant-design/icons';
import React, { useState, Fragment, useRef } from 'react'
import { Button, Card, notification, Table, Badge, Space } from 'antd'
import { getMusicUploadList, IGetUploadList, delMusic } from '../services'
import AddFile from './components/AddFile';
import UserInfo from './components/UserInfo'
import { useMount } from 'ahooks'
import { connect } from 'umi'
import * as Format from '@/utils/Format'
import { _musicOriginal } from '@/utils/type';
import Search from './components/Search'
import { FormInstance } from 'antd/lib/form';


const FileList = (props: any) => {
  const [loading, setLoading] = useState(false)
  const [delLoading, setDelLoading] = useState(false)
  const [actionModal, setActionModal] = useState(false)
  const [musicInfo, setManagerInfo] = useState(undefined)
  const [list, setList] = useState([])
  const [lastId, setLastId] = useState('0')
  const [selectedRowKeys, setSelectedRowKeys] = useState([])
  const [total, setTotal] = useState(0)
  const [noMore, setNoMore] = useState(false)

  const searchFormRef = useRef<FormInstance>()


  useMount(() => {
    //获取上传列表
    fetchList('0')
  })

  //获取上传列表
  const fetchList = async (id: string) => {
    const formData: any = searchFormRef.current?.getFieldsValue()
    const params: IGetUploadList = {
      lastId: id,
      sceneType: 1,
      musicName: formData.musicName,
      musicSinger: formData.musicSinger,
      shelfStatus: formData.shelfStatus,
    }
    if (loading) return
    await setLoading(true)
    const res = await getMusicUploadList(params)
    setLoading(false)
    if (res.success) {
      setTotal(res.data.total || 0)
      //当前获取页的列表长度，给删除的时候清空用
      const length = res.data.record.list.length
      setLastId(res.data.record.lastId)
      if (length === 0 || length < res.data.record.pageSize) {
        setNoMore(true)
      }
      if (id !== '0') {
        setList(list.concat(res.data.record.list))
      } else {
        setList(res.data.record.list)
      }
    }
  }

  const AddOption = () => {
    return (
      <Button type="primary"
        onClick={() => {
          setActionModal(true)
          setManagerInfo(undefined)
        }}
        icon={<PlusOutlined />}
      >上传歌曲</Button>
    )
  }

  const testLog = () => {
    console.log(selectedRowKeys)
  }

  //翻页
  const handlePage = () => {
    fetchList(lastId)
  }

  const loadMore =
    !noMore ? (
      <div
        style={{
          textAlign: 'center',
          marginTop: 12,
          height: 32,
          lineHeight: '32px',
        }}
      >
        <Button onClick={handlePage}>加载更多</Button>
      </div>
    ) : <div style={{ textAlign: 'center', color: '#999', paddingTop: 10 }}>暂无更多</div>;

  const columns = [
    {
      title: '名称',
      dataIndex: 'musicName',
      key: 'musicName',
    },
    {
      title: '演唱者',
      dataIndex: 'musicSinger',
      key: 'musicSinger',
    },
    {
      title: '状态',
      dataIndex: 'shelfStatus',
      key: 'shelfStatus',
      render: (shelfStatus: any) => (
        <Fragment>
          {shelfStatus === 0 && <Badge text="已下架" status="error"></Badge>}
          {shelfStatus === 1 && <Badge text="正常" status="success"></Badge>}
        </Fragment>
      )
    },
    {
      title: '类型',
      dataIndex: 'original',
      key: 'original',
      render: (original: any) => _musicOriginal[original]
    },
    {
      title: '下载次数',
      dataIndex: 'downloadCount',
      key: 'downloadCount'
    },
    {
      title: 'mp3',
      dataIndex: 'musicUrl',
      key: 'musicUrl',
      render: (musicUrl: any) => <audio controls src={musicUrl}></audio>
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      key: 'createTime',
      render: (createTime: any) => Format.date(createTime, 'yyyy-MM-dd HH:mm')
    },
    // {
    //   title: '操作',
    //   dataIndex: 'option',
    //   key: 'option',
    //   render: (option: any, record: any) => (
    //     <Fragment>
    //       <Popconfirm title="确定删除吗？" onConfirm={() => onDelete(record)}>
    //         <a>删除</a>
    //       </Popconfirm>
    //     </Fragment>
    //   )
    // },
  ]

  //删除
  const onDelete = async () => {
    await setDelLoading(true)
    if (delLoading) return
    const res = await delMusic({ musicIds: selectedRowKeys.join(',') })
    setDelLoading(false)
    if (res.success) {
      notification.success({
        message: '删除成功'
      })
      const newList: [] = []
      const listSet = new Set(selectedRowKeys)
      for (let item of list) {
        if (!listSet.has(item['musicId'])) {
          newList.push(item)
        }
      }
      setList([...newList])
      setSelectedRowKeys([])
    }
  }

  return (
    <PageContainer
      content={<UserInfo info={props.user.currentUser} total={total} />}
    >
      <Card title={<span onClick={testLog}>已上传歌曲</span>}
        extra={
          <Space>
            <AddOption />
            <Button type="primary" icon={<DeleteOutlined />} onClick={onDelete} disabled={selectedRowKeys.length === 0}>删除歌曲</Button>
          </Space>

        }
      >
        <Search
          formRef={searchFormRef}
        />
        <Space style={{ marginBottom: 20 }}>
          <Button icon={<SyncOutlined />} onClick={() => searchFormRef.current?.resetFields()}>
            重置
            </Button>
          <Button
            type="primary"
            loading={loading}
            icon={<SearchOutlined />}
            onClick={() => fetchList('0')}
          >
            查询
           </Button>
        </Space>
        <Table
          loading={loading}
          dataSource={list}
          rowKey="musicId"
          pagination={false}
          columns={columns}
          rowSelection={{
            type: 'checkbox',
            selectedRowKeys,
            onChange: (keys: any) => setSelectedRowKeys(keys)
          }}
        />
        {loadMore}
      </Card>
      {/* 添加-编辑音乐 */}
      <AddFile
        drawerProps={{
          visible: actionModal,
          width: 500,
          title: musicInfo ? '编辑音乐' : '添加音乐',
          onClose: () => setActionModal(false)
        }}
        info={musicInfo}
        afterAction={() => {
          setActionModal(false)
          fetchList('0')
        }}
      />
    </PageContainer>
  )
}

export default connect((user: any) => user)(FileList)