/**
 * 添加管理员
 */

// {/* 添加-编辑管理员 */ }
// <AddManager
//   drawerProps={{
//     visible: actionModal,
//     width: 500,
//     title: musicInfo ? '编辑管理员' : '添加管理员',
//     onClose: () => setActionModal(false)
//   }}
//   info={musicInfo}
//   afterAction={() => {
//     actionRef.current?.reload()
//     setActionModal(false)
//   }}
// />

import React, { useState, useEffect, Fragment } from 'react'
import { Form, Input, Button, notification, message, Drawer, Select } from 'antd'
import { addMusic, updateManager, getMusicUploadConfig } from '../../services'
import { objFilter } from '@/utils/base';
import MyUpload from '@/components/Custom/MyUpload';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};

interface IProps {
  drawerProps: {
    width?: number,
    title?: string,
    onClose: any,
    visible: boolean
  },
  info: {
    nickname: string,
    name: number,
    tid: string
  } | undefined,
  afterAction?: any
}

export default (props: IProps) => {
  const { drawerProps, info } = props

  const [form] = Form.useForm();
  const [submitLoading, setSubmitLoading] = useState<boolean>(false)
  const [uploadRef, setUploadRef] = useState<any>()

  useEffect(() => {
    if (drawerProps.visible) {
      initForm()
    }
  }, [drawerProps.visible, info])

  //写入
  const initForm = async () => {
    if (info) {
      form.setFieldsValue({
        nickname: info.nickname,
      })
    }
  }

  //提交
  const onSubmit = () => {
    form.validateFields().then(async (values) => {
      // console.log(values)
      if (uploadRef.state.fileList.length === 0) {
        message.error('请上传音乐文件')
        return
      }
      const params: any = {
        ...values,
        tid: info ? info.tid : '',
        musicUrl: uploadRef.state.fileList[0].url
      }
      objFilter(params)
      console.log('提交', params)
      if (submitLoading) return
      await setSubmitLoading(true)
      const res = info ? await updateManager(params) : await addMusic(params)
      setSubmitLoading(false)
      if (res.success) {
        notification.success({
          message: info ? '编辑成功' : '添加成功'
        })
        form.resetFields()
        uploadRef.setState({ fileList: [] })
        if (props.afterAction) {
          props.afterAction()
        }
      }
    })
  }

  return (
    <Drawer
      {...drawerProps}
      footer={
        <Button loading={submitLoading} type="primary" onClick={onSubmit}>{info ? '确定编辑' : '确定添加'}</Button>
      }
    >
      <Form
        form={form}
        {...formItemLayout}
      >
        <Fragment>
          <Form.Item
            label="歌曲名"
            name="musicName"
            rules={[{ message: '请输入歌曲名', required: true }]}
          >
            <Input placeholder="歌曲名" />
          </Form.Item>

          <Form.Item
            label="演唱者"
            name="musicSinger"
            rules={[{ message: '请输入演唱者', required: true }]}
          >
            <Input placeholder="演唱者" />
          </Form.Item>

          <Form.Item
            label="歌曲类型"
            name="original"
            rules={[{ message: '请选择歌曲类型', required: true }]}
          >
            <Select placeholder="歌曲类型">
              <Select.Option key={1} value={1}>原唱</Select.Option>
              <Select.Option key={0} value={0}>伴奏</Select.Option>
            </Select>
          </Form.Item>

          <Form.Item
            label="音乐文件"
            required
            extra="仅限mp3格式，不超过20M"
          >
            <MyUpload
              type="file"
              requestUrl={getMusicUploadConfig}
              num={1}
              saveData={(ref: any) => setUploadRef(ref)}
              limitType="mp3"
              needSize={20 * 1024 * 1024}
            />
          </Form.Item>
        </Fragment>
      </Form>
    </Drawer>
  )
}