import request from '@/utils/request';
import { stringify } from 'qs';

//管理员操作日志分页列表
export interface IGetPageList {
  pageIndex: number,
  pageSize: number,
  //编号
  traceId?: string,
  //方法名称
  method?: string,
  //管理员信息
  adminInfo?: string,
  //IP地址
  ip?: string,
  //开始时间
  startTime?: number,
  //结束时间
  endTime?: number,
}

//管理员操作日志分页列表
export async function getPageList(params: IGetPageList) {
  return request(`/wazhima/mgt/operate/his/getPageList`, {
    method: 'POST',
    data: params
  })
}

//管理员充值WOS
export interface IRechargeWOS {
  userId: string,
  amount: number
}
export async function rechargeWOS(params: IRechargeWOS) {
  return request(`/wazhima/mgt/finance/rechargeWOS`, {
    method: 'POST',
    data: params
  })
}

//管理员列表
export interface IGetManagerList {
  pageIndex: number,
  pageSize: number,
  //状态
  status?: number,
  //昵称
  nickname?: string,
  //手机号
  phone?: number,
}
export async function getManagerList(params: IGetManagerList) {
  return request(`/wazhima/mgt/admin/getPageList`, {
    method: 'POST',
    data: params
  })
}

//管理员-更新状态
export interface IUpdateManagerStatus {
  //状态
  status?: number,
  //管理员id
  tid?: string,
}
export async function updateManagerStatus(params: IUpdateManagerStatus) {
  return request(`/wazhima/mgt/admin/updateStatus`, {
    method: 'POST',
    data: params
  })
}

//管理员-创建
export interface IUpdateManager {
  //密码
  pwd: number,
  //手机号
  phone: number,
  //昵称
  nickname: string,
  //管理员ID
  tid: string
}
export async function updateManager(params: IUpdateManager) {
  return request(`/wazhima/mgt/admin/update`, {
    method: 'POST',
    data: params
  })
}

//获取上传列表
export interface IGetUploadList {
  //最后一条id
  lastId: string,
  sceneType: number,
  musicName: string,
  musicSinger: string,
  shelfStatus: number,
}
export async function getMusicUploadList(params: IGetUploadList) {
  return request(`/api-app/v1/music/getUploadList?${stringify(params)}`)
}

//添加音乐
export interface IAddMusic {
  //音乐名
  musicName: string,
  //演唱者
  phone: string,
  //音乐地址
  musicUrl: string,
  //1：原唱 0：伴奏
  original: 1 | 0
}
export async function addMusic(params: IAddMusic) {
  return request(`/api-app/v1/music/addMusic`, {
    method: 'POST',
    data: params
  })
}

//获取音乐上传配置
export async function getMusicUploadConfig(params: IGetUploadList) {
  return request(`/api-common/v1/data/getMusicUploadConfig?${stringify(params)}`)
}

//删除音乐
export interface IDelMusic {
  //音乐名
  musicIds: string,
}
export async function delMusic(params: IDelMusic) {
  return request(`/api-app/v1/music/delMusic`, {
    method: 'POST',
    data: params
  })
}